Monty Python's Flying Circus: Just the Words - Episode 29

# Episode Twenty-nine

'The Money Programme'
'There is nothing quite so wonderful as money' (song)
Erizabeth L
Fraud film squad
Salvation fuzz
Jungle restaurant
Apology for violence and nudity
Ken Russell's 'Gardening Club'
The Lost World of Roiurama
Six more minutes of Monty Python's Flying Circus
Argument clinic
Hitting on the head lessons
Inspector Flying Fox of the Yard
One more minute of Monty Python's Flying Circus

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Opening title sequence and signature tune for 'The Money Programme'. Set with presenter and two guests. Close up on presenter.
Presenter | Good evening and welcome to 'The Money Programme'. Tonight on 'The Money Programme', we're going to look at money. Lots of it. On film, and in the studio. Some of it in nice piles, others in lovely clanky bits of loose change, some of it neatly counted into fat little hundreds, delicate fivers stuffed into bulging wallets, nice crisp clean cheques, pert pieces of copper coinage thrust deep into trouser pockets, romantic foreign money rolling against the thigh with rough familiarity, (starting to get excited) beautiful wayward curlicued banknotes, filigree copperplating cheek by jowl with tumbling hexagonal milled edges, rubbing gently against the terse leather of beautifully balanced bank books (collects himself) I'm sorry. But I love money. All money. I've always wanted money.(getting worked up again) To handle. To touch. The smell of the rain-washed florin. The lure of the lira. (standing on the desk) The glitter and the glory of the guinea. The romance of the rouble. The feel of the franc, the heel of the Deutschmark. The cold antiseptic sting of the Swiss franc, and the sunburnt splendor of the Australian dollar.
| (sings to piano accompaniment) I've got ninety thousand pounds in my pajamas. I've got forty thousand French francs in my fridge. I've got lots and lots of lira, Now the deutschmark's getting dearer, And my dollar bill could buy the Brooklyn Bridge.
| Five singers (male) in Welsh (women's) national costume come on. A Welsh harpist joins them.
All | There is nothing quite as wonderful as money, There is nothing quite as beautiful as cash, Some people say it's folly But I'd rather have the lolly With money you can make a smash.
Presenter | There is nothing quite as wonderful as money There is nothing like a newly minted pound
All | Everyone must hanker For the butchness of a banker It's accountancy that makes the world go round.
Presenter | You can keep your Marxist ways For it's only just a phase.
All | For its money, money, money, Makes the world go round. (a shower of paper notes descends) Money, money, money, money, money, money!
| The 'It's' man
Man | It's...
| Animated titles.
Voice | Monty Python's Flying Circuses.
| Exterior of an Elizabethan palace. Elizabethan music. An Elizabethan messenger on a moped, comes up the drive and drives in through the front door.
| SUPERIMPOSED CAPTION: 'ERIZABETH L'
| Cut to a long corridor. The messenger appears mopeding along the corridor very fast. He leaps off the moped and hands it to a guard at a door. The guard places the moped on a rack and the messenger enters the door going past three trumpeters who play a fanfare. He approaches a clerical figure, who stands at yet another door.
| SUPERIMPOSED CAPTIONS: 'EPISODE THREE' and 'THE ALMALDA'
Messenger | I bling a dispatch flom Prymouth.
Clerk | Flom Prymouth?
Messenger | Flow Sil Flancis Dlake.
Clerk | Entel and apploach the thlone.
| The doors open. The messenger leaps on another moped and rides up to the throne on which sits Elizabeth surrounded by her courtiers, all of who are on motorized bicycles.
Queen | What news flom Prymouth?
Messenger | Dlake has sighted the Spanish Freet, youl Majesty.
Queen | So! Phirip's garreons ale hele. How many?
Messenger | One hundled and thilty-six men of wal.
Leicester | Broody herr.
Queen | Is Dlake plepaled?
Messenger | He has oldeled the whore freet into the Blitish Channer.
Queen | So, we must to Tirbuly. Reicestel! Sil Wartel Lareigh! Groucester! We sharr lide to...
| Enter Japanese director.
Japanese | Groucestel! Groucestel! Not Groucester. Come on, ret's get this light. Reicestel!
Leicester | Yes.
Japanese | That was telliber.
Leicester | What?
Japanese | Telliber.
Leicester | Oh! Solly.
Japanese | When you have a rine, ling your berr.
Leicester | Ling my berr?
Japanese | (linging his berr for him) Ling ling. Rike this. And cut the broody herr. Erizabeth!
Queen | (cheesed off) Yes?
Japanese | You should be on a bicycer.
Queen | Why?!
Japanese | You rook odd rike that.
Queen | I do not look odd like this - it's that lot that looks odd. It's bleeding weird having half the Tudor nobility ligging around on motorized bicycles.
Japanese | It's vely sullearist.
Queen | Horsefeathers!
Leicester | Listen mate. I'm beginning to have my doubts about you.
Japanese | What do you mean?
Leicester | I'm telling you straight, mate. I don't think you're Luchino Visconti at all.
Japanese | Of course I am. Me vely impoltant Itarian firm dilectol.
Queen | You are a Nip.
Japanese | Lubbish! Me genuine wop. (sings) Alliveldelchi Loma...
Leicester | He's bluffing.
Japanese | (sings) Vo-oorale... Ooh ... Is that the time, I must fry.
| The door opens. lnspector Leopard runs through the door followed by a copper.
Inspector | Not so fast, Yakomoto. (trumpeters play a fanfare) Shut up! (fanfare stops) Allow me to introduce myself. I am Inspector Leopard of Scotland Yard, Special Fraud Film Director Squad.
Court | Leopard of the Yard!
Inspector | The same. Only more violent. (he demonstrates this by kneeing the copper in the balls) Right, Slit Eyes Yakomoto, I'm arresting you for the impersonation of Signor Luchino Visconti, famous Italian director of such movie classics as 'Ossessione' 1942, 'La Tetra Trema' 1948, and 'Bellissima' 1951 - a satisfying ironic slice-of-life drama. 1957 brought to the silver screen his 'I Bianche Notre' adapted by Dostoyevsky, a mannered and romantic melancholy of snow and mist and moonlit encounters on canal bridges. 'Boccaccio 70' followed five years later and the following year saw 'The Leopard'! So impressed was I with this motion picture treatment of the Risorgimento that I went along to Somerset House and changed me own name to Leopard, preferring it to me original handle, 'Panther' (Aargh). I digress. 1969 saw 'The Damned', a Götterdämmerung epic of political and industrial shennanigans in good old Nazi Germany, starring Helmut Berger as a stinking transvestite what should have his face sawn off, the curvaceous Charlotte Rampling as a bit of tail, and the impeccable Dirk Bogarde as Von Essen. The association of the latter with Signor Visconti fructified with Dirk's magnificent portrayal of the elderly poof what expires in Venice. And so, Yakomoto... blimey, he gone! Never mind. I'll have you instead. (grabs the queen)
Queen | What?
Inspector | I haven't got time to go chasing after him, there's violence to be done.
| ANIMATION: sketch about violence.
| Cut to a kitchen. A man and woman listening to a radio.
Radio Voice | I would like to ask the team what they would do if they were Hitler.
Man's Voice | Gerald?
Another Voice | Well I'd annex the Sudeterland and sign a non-aggression pact with Russia.
First Man's Voice | Norman?
Norman's Voice | Well I'd do the Reichstag bathroom in purples and golds and ban abortion on demand.
Woman | (Switching the radio off) Liberal rubbish. Klaus ...What do you want with your jugged fish?
Man | Halibut.
Woman | The jugged fish is halibut.
Man | Well, what fish have you got that isn't jugged?
Woman | Rabbit.
Man | What? Rabbit fish?
Woman | Yes. It's got fins.
Man | Is it dead?
Woman | Well, it was coughing up blood last night.
Man | All right I'll have the dead unjugged rabbit fish.
| CAPTION: 'ONE DEAD UNJUGGED RABBIT FISH LATER'
Man | Well that was really horrible.
Woman | You're always complaining.
Man | What's for afters?
Woman | Well there's rat cake ... rat sorbet ... rat pudding ... or strawberry tart.
Man | Strawberry tart?!
Woman | Well, it's got some rat in it.
Man | How much?
Woman | Three (rather a lot really).
Man | ... well, I'll have a slice without so much rat in it.
| CAPTION: 'ONE SLICE OF STRAWBERRY TART WITHOUT SO MUCH RAT IN IT LATER'
Man | Appalling.
Woman | Moan, moan, moan.
| Enter their son
Son | Hello, mum, hello, dad.
Man | Hello, son.
Son | There's a dead bishop on the landing.
Woman | Where did that come from?
Son | What do you mean?
Woman | What's its diocese?
Son | Well it looked a bit Bath and Wellsish to me.
Man | I'll go and have a look. (goes out)
Woman | I don't know who keeps bringing them in here.
Son | Well it's not me.
Woman | I've put three out by the bin and the dustmen won't touch 'em.
Man | (coming back) Leicester.
Woman | How do you know?
Man | Tattooed on the back of his neck. I'm going to call the police.
Woman | Shouldn't you call the Church?
Son | Call the Church police.
Man | ...all right. (shouts) The Church police!
| Enter two policemen with ecclesiastical accoutrements.
Church Policeman | Yus?
Woman | There's another dead bishop on the landing.
Church Policeman | Suffragan or diocesan?
Woman | How should I know?
Church Policeman | It's tatooed on the back of their neck. Ere! Is that rat tart?
Woman | Yes.
Church Policeman | Disgusting! Right! The hunt is on. (kneels) Oh Lord we beseech thee tell us who croaked Leicester.
| Organ music. A huge hand descends and points at the man.
Man | All right, it's a fair cop, but society is to blame.
Church Policeman | Agreed.
Man | I would like the three by the bin to be taken into consideration.
Church Policeman | Right. And now, I'd like to conclude this arrest with a hymn.
All | (singing) And did those feet in ancient times walk upon England's mountains green. (policemen escort the man out) And was the holy lamb of God on England's pleasant pastures seen.
| ANIMATION: bouncing Queen Victoria.
Voice Over | Meanwhile in the jungle next door.
| A steamy tropical jungle. A native guide leads four explorers in pith helmets and old-fashioned long shorts through the jungle. Cicada sounds and shrieks of predatory jungle birds. Intercut close ups of perspiring foreheads etc. The native guide keeps beckoning them to hurry. The jungle appears to get thicker: they have to push their way through the undergrowth. Finally the guide stops and points, with eyes staring. The four explorers cluster around and look over his shoulder. A neat clearing in the thick of the jungle. Tables set as in a London bistro with check cloths and big wooden pepper mills, candles and menus standing on each table. Sitting at the tables are six other explorers in pith helmets etc., eating and chatting. Clink of coffee cups.
First Explorer | What a simply super little place!
Second Explorer | Yes, they've done wonders with it. You know this used to be one of the most swampy disease infested areas of the whole jungle, and they've turned it into this smashing little restaurant. (across the restaurant the head waiter appears, dressed in black tie and tails just a bit too big for him; he beckons them to a table) Here you are Omkami, thank you. Hello, Mr Akwekwe.
Akwekwe | Hello, Mr Spare-Buttons-Supplied-With-The-Shirt. Nice to see you again.
Second Explorer | These are some of my fellow explorers: Sir Charles Farquarson, Brian Bailey, Betty Bailey and this is Mr Akwekwe, who started the whole place.
Third Explorer | It really is super.
Fourth Explorer | (who is dressed as a man and has a moustache) Terrific idea.
Akwekwe | May I recommend the alligator purees.
| Suddenly there is a hideous scream. We see a gorilla tear a man from his table at the back of the restaurant, in front of a tree and drag him back into the jungle. Awful shrieks are heard. Akwekwe runs into the jungle shouting, Terrible sounds of the unseen fight. Thrashing about of bushes in the distance. A shot rings out. Then silence also rings out. Akwekwe emerges, dragging the inert body of the customer whom he puts back in his chair. He slumps forward. Akwekwe comes back to the table in the foreground which has remained in the foreground throughout this preceding shot, with cut ins of the four explorers looking through the menu. Akwekwe has a bloodstained claw mark right across his face and chest and his dicky is torn and bloodstained.
Akwekwe | Now then, have you decided?
| He produces a notepad such as waiters always carry.
Second Explorer | Ye-es ... Well there's two avocado vinaigrette here and what are you going to have Brian?
Fourth Explorer | Er quiche lorraine for me, please.
Akwekwe | Right, so that's two avocado, one quiche ...
| Cut to close up of pygmy's evil face parting leaves and firing a blow-pipe. Cut to another table where two explorers are having coffee and cigars. One of them stiffens and then slumps firward. Cut to Akwekwe at the main table registering what has happened. We pan with him as he rushes over to the bushes. Sound of pygmies retreating into the bushes. Akwekwe shouts after him. We pan with Akwekwe as he walks over to the table where the customer has slumped forward. He pulls him up, looks at dart sticking out of his chest, tut tuts with annoyance and lets him slump back on to the table again. He returns to the main table.
Akwekwe | So, that's two avocado, one quiche ...
Third Explorer | And a soup of the day.
Akwekwe | Right. (sinister sound of jungle drums in distance; close up of look of fear in Akwekwe's eyes) And to follow?
Second Explorer | Two chicken à la reine, with sauce provençale.
First Explorer | And one scampi desirée.
Third Explorer | And boeuf bourguignon with a green salad.
| Jungle drums getting louder. Akwekwe shouts off towards the back of the clearing where we assume the kitchens mast be.
Akwekwe | Right on. Two chicken! One scampi! One boeuf with green salad!
| He casts yet another fearful glance in the direction of the ever-increasing drum beats.
Akwekwe | There may be ... a little delay.
Second Explorer | That's fine but we have to be out by three.
Akwekwe | Yes, sir. Yes, we'll try.
| The drum beats get louder. Shot of forest, rustling of bushes. Close up of Akwekwe's eyes. Another shot of forest. Drum beats louder. More rustling. Close up of Akwekwe's eyes and sweating forehead. Forest again and more noise. Close up of Akwekwe; he now has blood on his face, his eyes dilate with fear, the drum beats become deafening. Sudden cut to BBC world symbol.
Voice Over | The BBC would like to announce that the next scene is not considered suitable for family viewing. It contains scenes of violence, involving people's heads and arms getting chopped off, their ears nailed to trees, and their toenails pulled out in slow motion. There are also scenes of naked women with floppy breasts, and also at one point you can see a pair of buttocks and there's another bit where I'll swear you can see everything, but my friend says it's just the way he's holding the spear. (pulling himself together) Because of the unsuitability of the scene, the BBC will be replacing it with a scene from a repeat of 'Gardening Club' for 1958.
| A beautiful well-stocked garden bed. 'Gardening Club' music. After two seconds there are shrieks of licentious and lustful laughter. A nude woman pursues a city gent, both screaming with pleasure, into the middle of the flowerbed and they roll around smashing up the flowers in unbridled erotic orgy. Immediately two nuns run in to join the fun, followed by two Vikings, a gumby, a pantomime goose, etc. The whole of this orgy is speeded up.
| CAPTION: 'KEN RUSSELL'S GARDENING CLUB (1958)'
Voice Over | And now back to the story.
| Cut to the edge of the jungle. Emerging from the dense undergrowth are two pygmy warriors pulling the four explorers who are roped together. The pygmies carry spears. We lose the pygmies and hold just the explorers in frame, and track with them.
Third Explorer | That was a nasty business back at the restaurant.
First Explorer | Yes, I thought most places took Barclaycard nowadays.
Second Explorer | Where do you think they're taking us, Brian?
Fourth Explorer | God knows!
Third Explorer | (pointing, eyes wide with amazement) Look!
| Cut to a stock shot of a volcano. Thrilling chord. Cut back to explorers.
Second Explorer | (filled with awe) The sacred volcano Andu! Which no man has seen before.
Third Explorer | No, no, no, next to that.
| Cut to stock shot of collection of big chimneys in a brickworks. Another thrilling chord. Cut back to explorers.
First Explorer | The London Brick Company?
Third Explorer | No, no, no, no - next to that.
| Cut to stock shot of plateau of Roiurama. Yet another thrilling chord. Cut back to explorers.
First Explorer | The forbidden plateau of Roiurama, the Lost World, thrown up by mighty earth movements thousands of millions of years ago, where strange primeval creatures defying evolution, lurk in the dark, impenetrable forests, cut off forever from the outside world.
Second Explorer | I still can't see it.
Fourth Explorer | You don't think that's where they're taking us?
Third Explorer | Yes, and God knows what we'll find there.
| A pigmy native rushes up from behind them, holding a script.
Native | What page please?
Second Explorer | What?
Native | (with a trace of irritation) What page in the script?
Second Explorer | (whispered) Page 7.
Native | (he speaks the lines over to himself) 'Come on, you dogs, we have far to go. We must lose no time'. (tries with eyes shut) 'Come on, you dogs, we have far to go. We must lose no time'. 'Come on you dogs'. (throws away the script, starts to push them roughly) Come on you dogs, we have time to lose, this has gone too far.
| Stock film of Houses of Parliament from across the Thames.
Voice Over | Meanwhile back in London ... at the British Explorers' Club in the Mall...
| Cut to the leather-armchaired hallway of a London club. In four of the chairs sit men in polar explorers' kit - furs, iced-over goggles, etc. - reading newspapers. At one chair sits a man in Norfolk jacket and plus fours. Around his neck he wears a sign saying 'Our Hero'. He is reading a newspaper but obviously has something else on his mind. Suddenly he throws the paper down and gets up. He walks over to the porter's desk. As he does this a polar expedition with four huskies, a sled, and two explorers pass him. Our Hero goes up to the desk. A whiskery old porter stands behind it.
Our Hero | Any news of Betty Bailey's expedition, Hargreaves?
Hargreaves | Er ... um ... er...
Our Hero | (through clenched teeth) Page 9...
Hargreaves | (thumbing over page of script beneath counter) 'The Lost World of Roiurama'.
Our Hero | That's my line.
Hargreaves | Oh, sorry. 'Where were they going, sir'?
Our Hero | The Lost World of Roiurama.
Hargreaves | Yes sir, we've got a telegram.
Our Hero | Oh
Hargreaves | (reads it) Reads it. Expedition superb. Weather excellent. Everything wonderful.
Our Hero | I wonder what's gone wrong.
Hargreaves | For God's sake be careful...
Our Hero | (irritably) Wait a minute... I'm going to go... after them.
Hargreaves | For God's sake be careful, sir.
| Cut to film of the lost world. Tropical South American vegetation. Our four explorers from Jungle Restaurant and Ken Russell's Gardening Club sketches limp along exhaustedly.
Second Explorer | My God, Betty, we're done for...
Third Explorer | We'll never get out of here... we're completely lost, lost. Even the natives have gone.
First Explorer | Goodbye Betty, Goodbye Farquarson. Goodbye Brian. It's been a great expedition...
| Music. Cut to engraving of Crystal Palace.
| SUPERIMPOSED CAPTION: 'CRYSTAL PALACE 1851'
| Cut immediately back to jungle.
First Explorer | Great expedition ...
Third Explorer | All that'll be left of us will be a map, a compass and a few feet of film, recording our last moments...
First Explorer | Wait a moment!
Fourth Explorer | What is it?
First Explorer | If we're on film, there must be someone filming us.
Second Explorer | My God, Betty, you're right!
| They all look around, then gradually all notice the camera. They break out in smiles of relief, come towards the camera and greet the camera crew.
Third Explorer | Look! Great to see you!
First Explorer | What a stroke of luck!
Camera Crew | Hello! ...
First Explorer | Wait a minute!
Fourth Explorer | What is it again?
First Explorer | If this is the crew who were filming us . .. who's filming us now? Look!
| Cut to another shot which indudes the first camera crew and yet another camera crew with all their equipment. The director is dressed the same as Yakomoto, the director in 'Erizabeth L', only he is blacked up.
Director | (African accent) Cut there man! No! No good! How we going to get feeling of personal alienation of self from society with this load of Bulldog Drummond crap? When I was doing 'La Notte' wi' dat Monica Vitti gal she don't gimme none of this empire building shit, man ...
| Camera pans slightly to reveal a door in jungle. It opens and an inspector enters.
Inspector | Not so fast, Akarumba! Allow me to introduce myself. I'm Inspector Baboon of Scotland Yard's Special Fraud Film Director Squad, Jungle Division.
Fourth Explorer | Baboon of the Yard!
Inspector | Shut up! (shoots her) Right, Akarumba! I'm arresting you for impersonating Signor Michelangelo Antonioni, an Italian film director who co-scripts all his own films, largely jettisoning narrative in favour of vague incident and relentless character study . . . (during this harangue the credits start to roll, music very faint beneath his words) ... In his first film: 'Cronaca Di Un Areore' (1950), the couple are brought together by a shared irrational guilt. 'L'Amico' followed in 1955, and 1959 saw the first of Antonioni's world-famous trilogy, 'L'Avventura' - an acute study of boredom, restlessness and the futilities and agonies of purposeless living. In 'L'Eclisse', three years later, this analysis of sentiments is taken up once again. 'We do not have to know each other to love', says the heroine, 'and perhaps we do not have to love...' The 'Eclipse' of the emotions finally casts its shadow when darkness descends on a street corner. (the credits end; voice and picture start to fade)... Signor Antonioni first makes use of colour to underline...
| Fade to black and then to BBC world symbol
Continuity Voice | And now on BBC another six minutes of Monty Python's Flying Circus.
| A reception desk in a sort of office building.
Receptionist (Rita Davies) | Yes, sir?
Man | I'd like to have an argument please.
Receptionist | Certainly, sir. Have you been here before...?
Man | No, this is my first time.
Receptionist | I see. Do you want to have the full argument, or were you thinking of taking a course?
Man | Well, what would be the cost?
Receptionist | Yes, it's one pound for a five-minute argument, but only eight pounds for a course of ten.
Man | Well, I think it's probably best if I start with the one and see how it goes from there. OK?
Receptionist | Fine. I'll see who's free at the moment ... Mr. Du-Bakey's free, but he's a little bit conciliatory ... yes, try Mr. Barnard - Room 12.
Man | Thank you.
| The man walks down a corridor. He opens door 12. There is a man at a desk.
Mr Barnard | (shouting) What do you want?
Man | Well I was told outside ...
Mr Barnard | Don't give me that you snotty-faced heap of parrot droppings!
Man | What!
Mr Barnard | Shut your festering gob you tit! Your type makes me puke! You vacuous toffee-nosed malodorous pervert!
Man | Look! I came here for an argument.
Mr Barnard | (calmly) Oh! I'm sorry, this is abuse.
Man | Oh I see, that explains it.
Mr Barnard | No, you want room 12A next door.
Man | I see - sorry. (exits)
Mr Barnard | Not at all. (as he goes) Stupid git.
| Outside 12A. The man knocks on the door.
Mr Vibrating | (from within) Come in.
| The man enters the room. Mr Vibrating is sitting at a desk.
Man | Is this the right room for an argument?
Mr Vibrating | I've told you once.
Man | No you haven't.
Mr Vibrating | Yes I have.
Man | When?
Mr Vibrating | Just now!
Man | No you didn't.
Mr Vibrating | Yes I did!
Man | Didn't.
Mr Vibrating | Did.
Man | Didn't.
Mr Vibrating | I'm telling you I did!
Man | You did not!
Mr Vibrating | I'm sorry, is this a five minute argument, or the full half hour?
Man | Oh ... Just a five-minute one.
Mr Vibrating | Fine (makes a note of it; the man sists down) thank you. Anyway, I did.
Man | You most certainly did not.
Mr Vibrating | Now, let's get one thing quite clear. I most definitely told you!
Man | You did not.
Mr Vibrating | Yes I did.
Man | Didn't.
Mr Vibrating | Yes I did.
Man | Didn't.
Mr Vibrating | Yes I did!!
Man | Look, this isn't an argument.
Mr Vibrating | Yes it is.
Man | No it isn't, it's just contradiction.
Mr Vibrating | No it isn't.
Man | Yes it is.
Mr Vibrating | It is not.
Man | It is. You just contradicted me.
Mr Vibrating | No I didn't.
Man | Ooh, you did!
Mr Vibrating | No, no, no, no, no.
Man | You did, just then.
Mr Vibrating | No, nonsense!
Man | Oh, look this is futile.
Mr Vibrating | No it isn't.
Man | I came here for a good argument.
Mr Vibrating | No you didn't, you came here for an argument.
Man | Well, an argument's not the same as contradiction.
Mr Vibrating | It can be.
Man | No it can't. An argument is a connected series of statements to establish a definite proposition.
Mr Vibrating | No it isn't.
Man | Yes it is. It isn't just contradiction.
Mr Vibrating | Look, if I argue with you, I must take up a contrary position.
Man | But it isn't just saying 'No it isn't'.
Mr Vibrating | Yes it is.
Man | No it isn't, Argument is an intellectual process ... contradiction is just the automatic gainsaying of anything the other person says.
Mr Vibrating | No it isn't.
Man | Yes it is.
Mr Vibrating | Not at all.
Man | Now look!
Mr Vibrating | (pressing the bell on his desk) That's it. Good morning.
Man | But I was just getting interested.
Mr Vibrating | Sorry the five minutes is up.
Man | That was never five minutes just now!
Mr Vibrating | I'm afraid it was.
Man | No it wasn't.
Mr Vibrating | I'm sorry, I'm not allowed to argue any more.
Man | What!?
Mr Vibrating | If you want me to go on arguing you'll have to pay for another five minutes.
Man | But that was never five minutes just now ... oh Come on! (Vibrating looks round as though man was not there) This is ridiculous.
Mr Vibrating | I'm very sorry, but I told you I'm not allowed to argue unless you've paid.
Man | Oh. all right. (pays) There you are.
Mr Vibrating | Thank you.
Man | Well?.
Mr Vibrating | Well what?
Man | That was never five minutes just now.
Mr Vibrating | I told you I'm not allowed to argue unless you've paid!
Man | I've just paid.
Mr Vibrating | No you didn't.
Man | I did! I did! I did!
Mr Vibrating | No you didn't.
Man | Look I don't want to argue about that.
Mr Vibrating | Well I'm very sorry but you didn't pay.
Man | Aha! Well if I didn't pay, why are you arguing ... got you!
Mr Vibrating | No you haven't.
Man | Yes I have ... if you're arguing I must have paid.
Mr Vibrating | Not necessarily. I could be arguing in my spare time.
Man | I've had enough of this.
Mr Vibrating | No you haven't.
Man | Oh shut up! (he leaves and sees a door marked complaints; he goes in) I want to complain.
Man in charge | You want to complain ... look at these shoes ... I've only had them three weeks and the heels are worn right through.
Man | No, I want to complain about ...
Man in charge | If you complain nothing happens ... you might just as well not bother. My back hurts and ... (the man exits, walks down the corridor and enters a room)
Man | I want to complain. ('Spreaders' who is just inside the door hits man on the head with a mallet) Ooh!
Spreaders | No, no, no, hold your head like this, and then go 'waaagh'! Try it again. (he hits him again)
Man | Waaghh!
Spreaders | Better. Better. But 'waaaaaghh'! 'Waaaagh'! Hold your hands here ...
Man | No!
Spreaders | Now. (hits him)
Man | Waagh!
Spreaders | That's it. That's it. Good.
Man | Stop hitting me!
Spreaders | What?
Man | Stop hitting me.
Spreaders | Stop hitting you?
Man | Yes.
Spreaders | What did you come in here for then?
Man | I came here to complain.
Spreaders | Oh I'm sorry, that's next door. It's being hit on the head lessons in here.
Man | What a stupid concept.
| Detective Inspector Fox enters
Fox | Right. Hold it there.
Man and Spreaders | What?
Fox | Allow me to introduce myself. I'm Inspector Fox of the Light Entertainment Police, Comedy Division, Special Flying Squad.
Man and Spreaders | Flying Fox of the Yard.
Fox | Shut up! (he hits the man with a truncheon)
Man | Ooooh?
Spreaders | No, no, no - Waagh!
Fox | And you. (he hits Spreaders)
Spreaders | Waagh!
Fox | He's good! You could learn a thing or two from him. Right now you two me old beauties, you are nicked.
Man | What for?
Fox | I'm charging you under Section 21 of the Strange Sketch Act.
Man | The what?
Fox | You are hereby charged that you did wilfully take part in a strange sketch, that is, a skit, spoof or humorous vignette of an unconventional nature with intent to cause grievous mental confusion to the Great British Public. (to camera) Evening all.
Spreaders | It's a fair cop.
Fox | And you tosh. (hits the man)
Man | WAAAGH!
Fox | That's excellent! Right, come on down the Yard.
| Another inspector arrives.
Inspector | Hold it. Hold it. Allow me to introduce myself. I'm Inspector Thompson's Gazelle of the Programme Planning Police, Light Entertainment Division, Special Flying Squad.
Fox | Flying Thompson's Gazelle of the Yard!
Inspector | Shut up! (he hits him)
Fox | Waaaagh!
Spreaders | He's good.
Inspector | Shut up! (hits Spreaders)
Spreaders | WAAGH!
Man | Rotten. (he gets hit) WAAAGH!
Inspector | Good. Now I'm arrestin' this entire show on three counts: one, acts of self-conscious behaviour contrary to the 'Not in front of the children' Act, two, always saying 'It's so and so of the Yard' every time the fuzz arrives and, three, and this is the cruncher, offenses against the 'Getting out of sketches without using a proper punchline' Act, four, namely, simply ending every bleedin' sketch by just having a policeman come in and... wait a minute.
| Another policeman enters.
Policeman | Hold it. (puts his hand on Inspector Thompson's Gazelle's shoulder)
Inspector | It's a fair cop.
| A large hairy hand appears through the door and claps him on the shoulder.
| CAPTION: 'THE END'
| Cut to BBC world symbol.
Announcer's Voice | And now on BBC 1, one more minute of Monty Python's Flying Circus.